@@ -15,6 +15,7 @@ j <- InstantR(Nactive=100,Ncontrol=97)
 k <- PieceExponential(start=c(0,5,10),lambda=c(0.01,0.02,0.03))
 l <- MixExp(props=c(0.7,0.3),lambda=c(0.02,0.01))
 m <- MixWei(props=c(0.3,0.7),alphas=c(100,50),betas=c(1,1))
+n <- PieceRMaxF(matrix(c(1,2,3,4,5,10,15,20),ncol=2),ratio=1.5,maxF=13)
 x <- c(30,1.1,2)
 names(x) <- c("scale","shape","family")
 
@@ -44,6 +45,8 @@ test_that("S4 architecture and constructors working as intended", {
   expect_equal(evaluateInvfunction(l, evaluateCDFfunction(l,10)),tolerance=0.001,10)
   expect_equal(evaluateInvfunction(m, evaluateCDFfunction(m,20)),tolerance=0.001,20)
   expect_equal(evaluateInvfunction(g, evaluateCDFfunction(g,4)),tolerance=0.001,4)
+  expect_equal(getMaxF(e), Inf)
+  expect_equal(getMaxF(n), 13)
 })
 
 context("Power Tests")
@@ -54,6 +57,7 @@ test_that("Power/Event Calculators working as intended", {
   expect_equal(ZV2power(Z=1.96),tolerance=0.0001,0.5)
   expect_equal(frontierpower(events=508,HR=0.75,startpower=0.9,Eratio=0.7),tolerance=0.000001,0.8967646)
   expect_equal(events2power(events=100,HR=0.75,ratio=0.5),tolerance=0.000001,0.2729824)
+  expect_equal(events2power(events=100,HR=0.75*1.3,ratio=0.5,HRbound=1.3),tolerance=0.000001,events2power(events=100,HR=0.75,ratio=0.5))
   expect_equal(frontierpower(events=100,HR=0.75,startpower=0.27,Rratio=0.5,Eratio=0.35,iter=20),tolerance=0.000001,0.2148509)
 })
 context("Loading examples 2")
@@ -62,7 +66,7 @@ bb <- nph_traj(active_ecurve=a,control_ecurve=b,active_dcurve=d,control_dcurve=d
 
 context("nph_traj structural testing")
 test_that("nph_traj runs and produces output of correct structure", {
-  expect_named(aa,c("active_ecurve","control_ecurve","active_dcurve","control_dcurve","rcurve","Summary"))
+  expect_named(aa,c("active_ecurve","control_ecurve","active_dcurve","control_dcurve","rcurve","HRbound","Summary"))
   expect_s4_class(aa$active_ecurve,"Curve")
   expect_s4_class(aa$control_ecurve,"Curve")
   expect_s4_class(aa$active_dcurve,"Curve")
@@ -112,7 +116,7 @@ context("trial simulation structural testing")
 test_that("simulate_trials is generating correctly-formatted output", {
   expect_true(is.matrix(cc))
   expect_identical(colnames(cc),c("Time","Censored","Trt","Iter"))
-  expect_identical(colnames(dd),c("Time","Censored","Trt","Iter","ETime","CTime","Rec_Time","Assess","RCTime"))
+  expect_identical(colnames(dd),c("Time","Censored","Trt","Iter","ETime","CTime","Rec_Time","Assess","Max_F","RCTime"))
   expect_equal(nrow(cc),3000)
   expect_true(max(cc[,"Time"]) < 30)
   expect_true(is.list(ee))
@@ -122,7 +126,7 @@ test_that("simulate_trials is generating correctly-formatted output", {
   expect_true(is.list(ff))
   expect_true(is.matrix(ff[[1]]))
   expect_equal(nrow(ff[[1]]),300)
-  expect_identical(colnames(ff[[1]]),c("Time","Censored","Trt","ETime","CTime","Rec_Time","Assess","RCTime"))
+  expect_identical(colnames(ff[[1]]),c("Time","Censored","Trt","ETime","CTime","Rec_Time","Assess","Max_F","RCTime"))
   expect_equal(sum(ff[[1]][,"Censored"],ff[[2]][,"Censored"],ff[[3]][,"Censored"],ff[[4]][,"Censored"],ff[[5]][,"Censored"],ff[[6]][,"Censored"],ff[[7]][,"Censored"],ff[[8]][,"Censored"],ff[[9]][,"Censored"],ff[[10]][,"Censored"]),2000)
   expect_true(is.matrix(gg))
   expect_equal(nrow(gg),2095)
@@ -145,7 +149,7 @@ test_that("simulate_trials_strata is working properly", {
   expect_equal(sum(ii[,"Censored"]),2025)
   expect_true(max(ii[,"Time"]) < 30)
   expect_true(is.list(jj))
-  expect_identical(colnames(jj[[1]]),c("Time","Censored","Trt","ETime","CTime","Rec_Time","Assess","RCTime","Stratum"))
+  expect_identical(colnames(jj[[1]]),c("Time","Censored","Trt","ETime","CTime","Rec_Time","Assess","Max_F","RCTime","Stratum"))
   expect_equal(nrow(jj[[1]]),300)
   expect_true(max(jj[[1]][,"Time"]) < 30)
 })
